import 'package:equatable/equatable.dart';
import 'package:flutter/material.dart';

@immutable
abstract class HomeFavoriteState extends Equatable {
  HomeFavoriteState([List props = const []]) : super();

  @override
  // TODO: implement props
  List<Object> get props => [];
}

class InitialHomeFavoriteState extends HomeFavoriteState {}

class HomeFavoriteLoading extends HomeFavoriteState {
  @override
  String toString() => 'HomeFavoriteLoading';
}

class HomeFavoriteSuccess extends HomeFavoriteState {
  @override
  String toString() {
    return 'HomeFavoriteSuccess';
  }
}

class HomeFavoriteFailure extends HomeFavoriteState {
  final String error;

  HomeFavoriteFailure(this.error);

  @override
  String toString() => 'HomeFavoriteFailure { error: $error }';
}


